==> benno-web-2.6.8.tgz: srv/benno/bennoweb/htdocs/ctrl/logoff.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */
require_once 'model/AppState.php';
$AppState = new AppState($USER->id);
$AppState->saveValue('searchMaskState',$App->getSession('searchMaskState'));
$AppState->saveValue('archive',$App->getSession('archive'));
$AppState->saveValue('isSpam',$App->getSession('isSpam'));

$exitview = $App->getSession('exitview');

try {
    $Backend->destroy_bennorest_session();
}
catch (Exception $e) {
    $App->log('[logoff] '.$e->getMessage());
}
$messages = array(
    'MSG'       => 'MSG_LOGOUT',
    'SKIN'      => $App->getSession('SKIN'),
    'LANG'      => $App->getSession('LANG')
);

$App->setSession('User','');
$App->setSession('ACCESS_LEVEL',0);
session_destroy();

$App->log('User '.$USER->id.' logged out',1);
if ($exitview) {
    $App->view = $exitview;
}
else {
    $App->redirect('default',$messages);
}
?>

==> benno-web-2.8.10.tgz: srv/benno/bennoweb/htdocs/ctrl/logoff.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */
require_once 'model/AppState.php';
$AppState = new AppState($USER->id);
$AppState->saveValue('searchMaskState',$App->getSession('searchMaskState'));
$AppState->saveValue('isSpam',$App->getSession('isSpam'));
$AppState->saveValue('resendMailto',$App->getSession('resendMailto'));

$lastArchive = $App->getSession('archive');
if ($lastArchive != 'SYSDATA') {    // -> FS#929
    $AppState->saveValue('archive',$lastArchive);
}

$exitview = $App->getSession('exitview');

try {
    $Backend->destroy_bennorest_session();
}
catch (Exception $e) {
    $App->log('[logoff] '.$e->getMessage());
}
$messages = array(
    'MSG'       => 'MSG_LOGOUT',
    'SKIN'      => $App->getSession('SKIN'),
    'LANG'      => $App->getSession('LANG')
);

$App->setSession('User','');
$App->setSession('ACCESS_LEVEL',0);
session_destroy();

$App->log('User '.$USER->id.' logged out',1);
if ($exitview) {
    $App->view = $exitview;
}
else {
    $App->redirect('default',$messages);
}
?>
